@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 6.1's 3.0 kernel.
+# This is a kernel build script for VineLinux 6.2's 3.4 kernel.
 #
 
 die () {
@@ -10,26 +10,26 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.0.77-1vl6.src.rpm ]
+if [ ! -r kernel-3.4.69-1vl6.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-6.1/updates/SRPMS/kernel-3.0.77-1vl6.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-6.2/updates/SRPMS/kernel-3.4.69-1vl6.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-3.0.77-1vl6.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-3.0.77-1vl6.src.rpm || die "Can't install source package."
+rpm --checksig kernel-3.4.69-1vl6.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-3.4.69-1vl6.src.rpm || die "Can't install source package."
 
 cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20131019.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20131201.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20131019.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20131019.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20131201.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20131201.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpm/SPECS/kernel-vl.spec . || die "Can't copy spec file."
+cp -p /root/rpm/SPECS/kernel34-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-vl.spec
-+++ kernel-vl.spec
-@@ -28,7 +28,7 @@
- %define patchlevel 77
+--- kernel34-vl.spec
++++ kernel34-vl.spec
+@@ -34,7 +34,7 @@
+ %define patchlevel 69
  %define kversion 3.%{sublevel}
  %define rpmversion 3.%{sublevel}.%{patchlevel}
 -%define release 1%{?_dist_release}
@@ -37,7 +37,7 @@ patch << "EOF" || die "Can't patch spec file."
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
-@@ -120,6 +120,9 @@
+@@ -126,6 +126,9 @@
  # to versions below the minimum
  #
  
@@ -47,27 +47,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -152,7 +155,7 @@
+@@ -158,7 +161,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 6.0.93, linux-firmware >= 20110601-1
+ %define kernel_prereq  fileutils, %{kmod}, initscripts >= 8.80, mkinitrd >= 6.0.93, linux-firmware >= 20110601-1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -705,6 +708,10 @@
+@@ -680,6 +683,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20131019.tar.gz
-+patch -sp1 < patches/ccs-patch-3.0-vine-linux-6.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20131201.tar.gz
++patch -sp1 < patches/ccs-patch-3.4-vine-linux-6.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -723,6 +730,9 @@
+@@ -698,6 +705,9 @@
  for i in *.config
  do 
  	mv $i .config 
@@ -78,7 +78,7 @@ patch << "EOF" || die "Can't patch spec file."
  	make ARCH=$Arch oldnoconfig
  	echo "# $Arch" > configs/$i
 EOF
-mv kernel-vl.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel34-vl.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
